# Copyright (c) 2012-2013 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/

# vim: set ts=4 sw=4 et:

Name:           gst123
Version:        0.3.3
Release:        2.11
License:        LGPL-2.0+
Summary:        GStreamer based Command Line Music Player
Url:            http://space.twc.de/~stefan/gst123.php
Group:          Productivity/Multimedia/Sound/Players
Source:         http://space.twc.de/~stefan/gst123/gst123-%{version}.tar.bz2
Source1:        gst123.desktop
# PATCH-FIX-PACKMAN TAG gst123-gtk2_backport_GDK_BLANK_CURSOR.patch pascal.bleser@opensuse.org -- No info available for this patch?
Patch2:         gst123-gtk2_backport_GDK_BLANK_CURSOR.patch
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
%if 0%{?suse_version} >= 1230
BuildRequires:  gstreamer-devel
BuildRequires:  gstreamer-plugins-base-devel
%else
BuildRequires:  glib2-devel >= 2.32
BuildRequires:  gstreamer-0_10-devel
BuildRequires:  gstreamer-0_10-plugins-base-devel
%endif
BuildRequires:  libstdc++-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The program gst123 is designed to be a more flexible command line player in the
spirit of ogg123 and mpg123, based on gstreamer. It plays all file formats
gstreamer understands, so if you have a music collection which contains
different file formats, like flac, ogg and mp3, you can use gst123 to play all
your music files.

%prep
%setup -q
%patch2 -p1

%build
%configure
make %{?_smp_flags} V=1

%install
%make_install
install -D -m0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/applications/%{name}.desktop"
%suse_update_desktop_file -r "%{name}" AudioVideo Player
%find_lang "%{name}" || echo -n >"%{name}.lang"

%if 0%{?suse_version} >= 1140
%post
%desktop_database_post
%endif

%if 0%{?suse_version} >= 1140
%postun
%desktop_database_postun
%endif

%files -f "%{name}.lang"
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS README TODO
%{_bindir}/gst123
%doc %{_mandir}/man1/gst123.1%{ext_man}
%{_datadir}/applications/%{name}.desktop

%changelog
* Wed Apr 23 2014 ohering@suse.de
- BuildRequire glib2-devel >= 2.32 due to GMutex/GCond usage
* Mon Jul 29 2013 malcolmlewis@opensuse.org
- Update to version 0.3.3:
  + Fix Issue 10: Local files not properly escaped when converted
    to URLs.
  + Added "-k, --skip=" option: skip first 'n' seconds
    [Tobias Bengfort].
- Updates from version 0.3.2:
  + Support building with gstreamer 1.0 or gstreamer 0.10
    (Issue 11).
  + Added "-a pulse" PulseAudio output support.
  + Fix time display updates (broken by introduction of quiet
    mode).
  + Properly quit player if none of the files in the playlist can
    be played.
  + Cleanup code to avoid compiler warnings.
- Rebase gst123-gtk2_backport_GDK_BLANK_CURSOR.patch.
* Sun Apr 22 2012 pascal.bleser@opensuse.org
- update to 0.3.1:
  * added quiet mode
  * ignore image files during playback
  * added keybinding 'n' for 'play next file'
* Thu Mar 29 2012 pascal.bleser@opensuse.org
- update to 0.3.0:
  * support visualization plugins during audio playback
* Fri Feb 17 2012 pascal.bleser@opensuse.org
- update to 0.2.2:
  * disable screensaver during video playback (via xdg-screensaver)
  * fixed includes to compile with gcc-4.7
  * fixed a problem with fullscreen/unfullscreen
* Sun Sep  4 2011 pascal.bleser@opensuse.org
- update to 0.2.1:
  * fixed minor memory leak
  * fix warnings due to wrong glib option parsing
  * use wikihtml2man for documentation (replaces old doxer based manpage)
* Tue Apr 12 2011 pascal.bleser@opensuse.org
- update to 0.2.0:
  * the behavior of the options --shuffle, --repeat, and --random is now
    identical to ogg123
  * the colon character is now supported in filenames
  * the "none" audio driver was added, which disables audio output
  * the --full-version option is supported, which prints versions of the
    libraries used by gst123
  * minor fixes were made
* Sun Jan 16 2011 pascal.bleser@opensuse.org
- update to 0.1.4:
  * a crash for "dumb" terminals was fixed
* Mon Nov 29 2010 pascal.bleser@opensuse.org
- update to 0.1.3:
  * support for m3u and pls playlists was added
  * JACK audio output is available now
  * the audio driver can be set using a configuration file (or on the command line, as before)
* Tue Jul  6 2010 pascal@links2linux.de
- update to 0.1.2:
  * adds an -a option to select the audio driver (OSS/ALSA) and device (/dev/dsp1, hw:1)
  * fixes a crash triggered when closing the video window
* Sat Jun 26 2010 pascal@links2linux.de
- update to 0.1.1:
  * the code was fixed to allow URIs in playlists
- changes from 0.1.0:
  * proper support for watching video files with gst123 has been added,
    including a full screen mode (f) and using keys (like page up, cursor left,
    etc.) within the video window
  * also hides the mouse in the video widget and uses the correct aspect ratio during zoom
  * GStreamer playbin2 is now used instead of playbin
  * option parsing was improved (--help, --help-gst, and --help-gtk work)
  * the ability to disable video stream (-x, --novideo) was added
  * pause / muted state is now printed in the status display
* Tue May 11 2010 pascal@links2linux.de
- update to 0.0.3:
  * fixes buggy key handling when keys are autorepeating
  * restores proper terminal settings after Ctrl+Z
  * adds keys for mute and volume control
  * displays the video codec when present
* Tue May  4 2010 pascal@links2linux.de
- initial package: 0.0.2
